@@ -4,7 +4,7 @@
 
 ;; Author: Bozhidar Batsov <bozhidar@batsov.com>
 ;; URL: http://github.com/bbatsov/zenburn-emacs
-;; Version: 2.6
+;; Version: 2.7.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -35,7 +35,8 @@
 
 (defgroup zenburn-theme nil
   "Zenburn theme."
-  :prefix "zenburn-theme-"
+  :group 'faces
+  :prefix "zenburn-"
   :link '(url-link :tag "GitHub" "http://github.com/bbatsov/zenburn-emacs")
   :tag "Zenburn theme")
 
@@ -50,11 +51,14 @@ defining them in this alist."
           :key-type (string :tag "Name")
           :value-type (string :tag " Hex")))
 
-(defcustom zenburn-use-variable-pitch nil
-  "Use variable pitch face for some headings and titles."
-  :type 'boolean
-  :group 'zenburn-theme
-  :package-version '(zenburn . "2.6"))
+(defvar zenburn-use-variable-pitch nil
+  "When non-nil, use variable pitch face for some headings and titles.")
+
+(defvar zenburn-scale-org-headlines nil
+  "Whether `org-mode' headlines should be scaled.")
+
+(defvar zenburn-scale-outline-headlines nil
+  "Whether `outline-mode' headlines should be scaled.")
 
 (defcustom zenburn-height-minus-1 0.8
   "Font size -1."
@@ -86,45 +90,36 @@ defining them in this alist."
   :group 'zenburn-theme
   :package-version '(zenburn . "2.6"))
 
-(defcustom zenburn-scale-org-headlines nil
-  "Whether `org-mode' headlines should be scaled."
-  :type 'boolean
-  :group 'zenburn-theme
-  :package-version '(zenburn . "2.6"))
-
-(defcustom zenburn-scale-outline-headlines nil
-  "Whether `outline-mode' headlines should be scaled."
-  :type 'boolean
-  :group 'zenburn-theme
-  :package-version '(zenburn . "2.6"))
-
 ;;; Color Palette
 
 (defvar zenburn-default-colors-alist
-  '(("zenburn-fg+1"     . "#FFFFEF")
+  '(("zenburn-fg-1"     . "#656555")
+    ("zenburn-fg-05"    . "#989890")
     ("zenburn-fg"       . "#DCDCCC")
-    ("zenburn-fg-1"     . "#656555")
+    ("zenburn-fg+1"     . "#FFFFEF")
+    ("zenburn-fg+2"     . "#FFFFFD")
     ("zenburn-bg-2"     . "#000000")
     ("zenburn-bg-1"     . "#2B2B2B")
+    ("zenburn-bg-08"    . "#303030")
     ("zenburn-bg-05"    . "#383838")
     ("zenburn-bg"       . "#3F3F3F")
     ("zenburn-bg+05"    . "#494949")
     ("zenburn-bg+1"     . "#4F4F4F")
     ("zenburn-bg+2"     . "#5F5F5F")
     ("zenburn-bg+3"     . "#6F6F6F")
-    ("zenburn-red+2"    . "#ECB3B3")
-    ("zenburn-red+1"    . "#DCA3A3")
-    ("zenburn-red"      . "#CC9393")
-    ("zenburn-red-1"    . "#BC8383")
-    ("zenburn-red-2"    . "#AC7373")
-    ("zenburn-red-3"    . "#9C6363")
-    ("zenburn-red-4"    . "#8C5353")
-    ("zenburn-red-5"    . "#7C4343")
     ("zenburn-red-6"    . "#6C3333")
+    ("zenburn-red-5"    . "#7C4343")
+    ("zenburn-red-4"    . "#8C5353")
+    ("zenburn-red-3"    . "#9C6363")
+    ("zenburn-red-2"    . "#AC7373")
+    ("zenburn-red-1"    . "#BC8383")
+    ("zenburn-red"      . "#CC9393")
+    ("zenburn-red+1"    . "#DCA3A3")
+    ("zenburn-red+2"    . "#ECB3B3")
     ("zenburn-orange"   . "#DFAF8F")
-    ("zenburn-yellow"   . "#F0DFAF")
-    ("zenburn-yellow-1" . "#E0CF9F")
     ("zenburn-yellow-2" . "#D0BF8F")
+    ("zenburn-yellow-1" . "#E0CF9F")
+    ("zenburn-yellow"   . "#F0DFAF")
     ("zenburn-green-5"  . "#2F4F2F")
     ("zenburn-green-4"  . "#3F5F3F")
     ("zenburn-green-3"  . "#4F6F4F")
@@ -181,7 +176,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(fringe ((t (:foreground ,zenburn-fg :background ,zenburn-bg+1))))
    `(header-line ((t (:foreground ,zenburn-yellow
                                   :background ,zenburn-bg-1
-                                  :box (:line-width -1 :style released-button)))))
+                                  :box (:line-width -1 :style released-button)
+                                  :extend t))))
    `(highlight ((t (:background ,zenburn-bg-05))))
    `(success ((t (:foreground ,zenburn-green :weight bold))))
    `(warning ((t (:foreground ,zenburn-orange :weight bold))))
@@ -203,6 +199,12 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(compilation-mode-line-run ((t (:foreground ,zenburn-yellow :weight bold))))
 ;;;;; completions
    `(completions-annotations ((t (:foreground ,zenburn-fg-1))))
+;;;;; customize
+   `(custom-variable-tag ((t (:foreground ,zenburn-blue :weight bold))))
+   `(custom-group-tag ((t (:foreground ,zenburn-blue :weight bold :height 1.2))))
+   `(custom-state ((t (:foreground ,zenburn-green+4))))
+;;;;; display-fill-column-indicator
+   `(fill-column-indicator ((,class :foreground ,zenburn-bg-05 :weight semilight)))
 ;;;;; eww
    '(eww-invalid-certificate ((t (:inherit error))))
    '(eww-valid-certificate   ((t (:inherit success))))
@@ -239,7 +241,7 @@ Also bind `class' to ((class color) (min-colors 89))."
      ((t (:foreground ,zenburn-green-2
                       :background ,zenburn-bg-05
                       :box (:line-width -1 :style released-button)))))
-   `(region ((,class (:background ,zenburn-bg-1))
+   `(region ((,class (:background ,zenburn-bg-1 :extend t))
              (t :inverse-video t)))
    `(secondary-selection ((t (:background ,zenburn-bg+2))))
    `(trailing-whitespace ((t (:background ,zenburn-red))))
@@ -393,6 +395,15 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(cfw:face-toolbar ((t (:background ,zenburn-blue-5))))
    `(cfw:face-toolbar-button-off ((t (:underline nil :inherit link))))
    `(cfw:face-toolbar-button-on ((t (:underline nil :inherit link-visited))))
+;;;;; centaur-tabs
+   `(centaur-tabs-default ((t (:background ,zenburn-bg :foreground ,zenburn-fg :box nil))))
+   `(centaur-tabs-selected ((t (:background ,zenburn-bg :foreground ,zenburn-fg+2 :box nil))))
+   `(centaur-tabs-unselected ((t (:background ,zenburn-bg-1 :foreground ,zenburn-fg-05 :box nil))))
+   `(centaur-tabs-selected-modified ((t (:background ,zenburn-bg :foreground ,zenburn-orange :box nil))))
+   `(centaur-tabs-unselected-modified ((t (:background ,zenburn-bg-1 :foreground ,zenburn-orange :box nil))))
+   `(centaur-tabs-active-bar-face ((t (:background ,zenburn-yellow :box nil))))
+   `(centaur-tabs-modified-marker-selected ((t (:inherit 'centaur-tabs-selected-modified :foreground ,zenburn-yellow :box nil))))
+   `(centaur-tabs-modified-marker-unselected ((t (:inherit 'centaur-tabs-unselected-modified :foreground ,zenburn-yellow :box nil))))
 ;;;;; cider
    `(cider-result-overlay-face ((t (:background unspecified))))
    `(cider-enlightened-face ((t (:box (:color ,zenburn-orange :line-width -1)))))
@@ -438,12 +449,13 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(debbugs-gnu-stale ((t (:foreground ,zenburn-orange))))
    `(debbugs-gnu-tagged ((t (:foreground ,zenburn-red))))
 ;;;;; diff
-   `(diff-added          ((t (:background ,zenburn-green-5 :foreground ,zenburn-green+2))))
+   ;; Please read (info "(magit)Theming Faces") before changing this.
+   `(diff-added          ((t (:background "#335533" :foreground ,zenburn-green))))
    `(diff-changed        ((t (:background "#555511" :foreground ,zenburn-yellow-1))))
-   `(diff-removed        ((t (:background ,zenburn-red-6 :foreground ,zenburn-red+1))))
-   `(diff-refine-added   ((t (:background ,zenburn-green-4 :foreground ,zenburn-green+3))))
+   `(diff-removed        ((t (:background "#553333" :foreground ,zenburn-red-2))))
+   `(diff-refine-added   ((t (:background "#338833" :foreground ,zenburn-green+4))))
    `(diff-refine-changed ((t (:background "#888811" :foreground ,zenburn-yellow))))
-   `(diff-refine-removed ((t (:background ,zenburn-red-5 :foreground ,zenburn-red+2))))
+   `(diff-refine-removed ((t (:background "#883333" :foreground ,zenburn-red))))
    `(diff-header ((,class (:background ,zenburn-bg+2))
                   (t (:background ,zenburn-fg :foreground ,zenburn-bg))))
    `(diff-file-header
@@ -506,23 +518,26 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(diredfl-read-priv ((t (:foreground ,zenburn-green-1))))
    `(diredfl-symlink ((t (:foreground ,zenburn-yellow))))
    `(diredfl-write-priv ((t (:foreground ,zenburn-magenta))))
+;;;;; doom-modeline
+   `(doom-modeline-bar  ((t (:background ,zenburn-yellow))))
+   `(doom-modeline-inactive-bar  ((t (:background nil))))
 ;;;;; ediff
-   `(ediff-current-diff-A ((t (:inherit diff-removed))))
-   `(ediff-current-diff-Ancestor ((t (:inherit ediff-current-diff-A))))
-   `(ediff-current-diff-B ((t (:inherit diff-added))))
-   `(ediff-current-diff-C ((t (:foreground ,zenburn-blue+2 :background ,zenburn-blue-5))))
+   `(ediff-current-diff-A ((t (:foreground ,zenburn-fg :background ,zenburn-red-4))))
+   `(ediff-current-diff-Ancestor ((t (:foreground ,zenburn-fg :background ,zenburn-red-4))))
+   `(ediff-current-diff-B ((t (:foreground ,zenburn-fg :background ,zenburn-green-2))))
+   `(ediff-current-diff-C ((t (:foreground ,zenburn-fg :background ,zenburn-blue-5))))
    `(ediff-even-diff-A ((t (:background ,zenburn-bg+1))))
    `(ediff-even-diff-Ancestor ((t (:background ,zenburn-bg+1))))
    `(ediff-even-diff-B ((t (:background ,zenburn-bg+1))))
    `(ediff-even-diff-C ((t (:background ,zenburn-bg+1))))
-   `(ediff-fine-diff-A ((t (:inherit diff-refine-removed :weight bold))))
-   `(ediff-fine-diff-Ancestor ((t (:inherit ediff-fine-diff-A))))
-   `(ediff-fine-diff-B ((t (:inherit diff-refine-added :weight bold))))
-   `(ediff-fine-diff-C ((t (:foreground ,zenburn-blue+3 :background ,zenburn-blue-4 :weight bold))))
+   `(ediff-fine-diff-A ((t (:foreground ,zenburn-fg :background ,zenburn-red-2 :weight bold))))
+   `(ediff-fine-diff-Ancestor ((t (:foreground ,zenburn-fg :background ,zenburn-red-2 weight bold))))
+   `(ediff-fine-diff-B ((t (:foreground ,zenburn-fg :background ,zenburn-green :weight bold))))
+   `(ediff-fine-diff-C ((t (:foreground ,zenburn-fg :background ,zenburn-blue-3 :weight bold ))))
    `(ediff-odd-diff-A ((t (:background ,zenburn-bg+2))))
-   `(ediff-odd-diff-Ancestor ((t (:inherit ediff-odd-diff-A))))
-   `(ediff-odd-diff-B ((t (:inherit ediff-odd-diff-A))))
-   `(ediff-odd-diff-C ((t (:inherit ediff-odd-diff-A))))
+   `(ediff-odd-diff-Ancestor ((t (:background ,zenburn-bg+2))))
+   `(ediff-odd-diff-B ((t (:background ,zenburn-bg+2))))
+   `(ediff-odd-diff-C ((t (:background ,zenburn-bg+2))))
 ;;;;; egg
    `(egg-text-base ((t (:foreground ,zenburn-fg))))
    `(egg-help-header-1 ((t (:foreground ,zenburn-yellow))))
@@ -543,6 +558,8 @@ Also bind `class' to ((class color) (min-colors 89))."
                                               :weight bold))))
    `(elfeed-search-tag-face ((t (:foreground ,zenburn-green))))
    `(elfeed-search-feed-face ((t (:foreground ,zenburn-cyan))))
+   `(elfeed-search-title-face ((t (:foreground ,zenburn-fg-05))))
+   `(elfeed-search-unread-title-face ((t (:foreground ,zenburn-fg :weight bold))))
 ;;;;; emacs-w3m
    `(w3m-anchor ((t (:foreground ,zenburn-yellow :underline t
                                  :weight bold))))
@@ -743,13 +760,15 @@ Also bind `class' to ((class color) (min-colors 89))."
      ((t (:foreground ,zenburn-green
                       :background ,zenburn-bg
                       :underline nil
-                      :box nil))))
+                      :box nil
+                      :extend t))))
    `(helm-source-header
      ((t (:foreground ,zenburn-yellow
                       :background ,zenburn-bg-1
                       :underline nil
                       :weight bold
-                      :box (:line-width -1 :style released-button)))))
+                      :box (:line-width -1 :style released-button)
+                      :extend t))))
    `(helm-selection ((t (:background ,zenburn-bg+1 :underline nil))))
    `(helm-selection-line ((t (:background ,zenburn-bg+1))))
    `(helm-visible-mark ((t (:foreground ,zenburn-bg :background ,zenburn-yellow-2))))
@@ -784,13 +803,23 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(helm-moccur-buffer ((t (:foreground ,zenburn-cyan :background ,zenburn-bg))))
    `(helm-mu-contacts-address-face ((t (:foreground ,zenburn-fg-1 :background ,zenburn-bg))))
    `(helm-mu-contacts-name-face ((t (:foreground ,zenburn-fg :background ,zenburn-bg))))
+;;;;; helm-lxc
+   `(helm-lxc-face-frozen ((t (:foreground ,zenburn-blue :background ,zenburn-bg))))
+   `(helm-lxc-face-running ((t (:foreground ,zenburn-green :background ,zenburn-bg))))
+   `(helm-lxc-face-stopped ((t (:foreground ,zenburn-red :background ,zenburn-bg))))
 ;;;;; helm-swoop
    `(helm-swoop-target-line-face ((t (:foreground ,zenburn-fg :background ,zenburn-bg+1))))
    `(helm-swoop-target-word-face ((t (:foreground ,zenburn-yellow :background ,zenburn-bg+2 :weight bold))))
+;;;;; highlight-numbers
+   `(highlight-numbers-number ((t (:foreground ,zenburn-blue))))
+;;;;; highlight-symbol
+   `(highlight-symbol-face ((t (:background ,zenburn-bg+2))))
+;;;;; highlight-thing
+   `(highlight-thing ((t (:background ,zenburn-bg+2))))
 ;;;;; hl-line-mode
    `(hl-line-face ((,class (:background ,zenburn-bg-05))
                    (t :weight bold)))
-   `(hl-line ((,class (:background ,zenburn-bg-05)) ; old emacsen
+   `(hl-line ((,class (:background ,zenburn-bg-05 :extend t)) ; old emacsen
               (t :weight bold)))
 ;;;;; hl-sexp
    `(hl-sexp-face ((,class (:background ,zenburn-bg+1))
@@ -937,19 +966,18 @@ Also bind `class' to ((class color) (min-colors 89))."
      ((t (:underline t))))
 ;;;;; magit
 ;;;;;; headings and diffs
+   ;; Please read (info "(magit)Theming Faces") before changing this.
    `(magit-section-highlight           ((t (:background ,zenburn-bg+05))))
    `(magit-section-heading             ((t (:foreground ,zenburn-yellow :weight bold))))
    `(magit-section-heading-selection   ((t (:foreground ,zenburn-orange :weight bold))))
-
-   `(magit-diff-added ((t (:inherit diff-added))))
-   `(magit-diff-added-highlight ((t (:inherit diff-refine-added))))
-   `(magit-diff-removed ((t (:inherit diff-removed))))
-   `(magit-diff-removed-highlight ((t (:inherit diff-refine-removed))))
-
    `(magit-diff-file-heading           ((t (:weight bold))))
-   `(magit-diff-file-heading-highlight ((t (:background ,zenburn-bg+05  :weight bold))))
-   `(magit-diff-file-heading-selection ((t (:background ,zenburn-bg+05
-                                                        :foreground ,zenburn-orange :weight bold))))
+   `(magit-diff-file-heading-highlight ((t (:background ,zenburn-bg+05 :weight bold))))
+   `(magit-diff-file-heading-selection ((t (:background ,zenburn-bg+05 :weight bold
+                                                        :foreground ,zenburn-orange))))
+   `(magit-diff-added                  ((t (:background ,zenburn-green-2))))
+   `(magit-diff-added-highlight        ((t (:background ,zenburn-green))))
+   `(magit-diff-removed                ((t (:background ,zenburn-red-4))))
+   `(magit-diff-removed-highlight      ((t (:background ,zenburn-red-3))))
    `(magit-diff-hunk-heading           ((t (:background ,zenburn-bg+1))))
    `(magit-diff-hunk-heading-highlight ((t (:background ,zenburn-bg+2))))
    `(magit-diff-hunk-heading-selection ((t (:background ,zenburn-bg+2
@@ -958,8 +986,8 @@ Also bind `class' to ((class color) (min-colors 89))."
                                                         :foreground ,zenburn-bg+2))))
    `(magit-diff-context-highlight      ((t (:background ,zenburn-bg+05
                                                         :foreground "grey70"))))
-   `(magit-diffstat-added   ((t (:foreground ,zenburn-green+4))))
-   `(magit-diffstat-removed ((t (:foreground ,zenburn-red))))
+   `(magit-diffstat-added              ((t (:foreground ,zenburn-green+4))))
+   `(magit-diffstat-removed            ((t (:foreground ,zenburn-red))))
 ;;;;;; popup
    `(magit-popup-heading             ((t (:foreground ,zenburn-yellow  :weight bold))))
    `(magit-popup-key                 ((t (:foreground ,zenburn-green-2 :weight bold))))
@@ -1143,12 +1171,31 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(neo-vc-conflict-face ((t (:foreground ,zenburn-red+1))))
    `(neo-vc-missing-face ((t (:foreground ,zenburn-red+1))))
    `(neo-vc-ignored-face ((t (:foreground ,zenburn-fg-1))))
+;;;;; notmuch
+   `(notmuch-crypto-decryption ((t (:foreground ,zenburn-bg :background ,zenburn-magenta))))
+   `(notmuch-crypto-part-header ((t (:foreground ,zenburn-blue+1))))
+   `(notmuch-crypto-signature-bad ((t (:foreground ,zenburn-bg :background ,zenburn-red))))
+   `(notmuch-crypto-signature-good ((t (:foreground ,zenburn-bg :background ,zenburn-green+1))))
+   `(notmuch-crypto-signature-good-key ((t (:foreground ,zenburn-bg :background ,zenburn-orange))))
+   `(notmuch-crypto-signature-unknown ((t (:foreground ,zenburn-bg :background ,zenburn-red))))
+   `(notmuch-hello-logo-background ((t (:background ,zenburn-bg+2))))
+   `(notmuch-message-summary-face ((t (:background ,zenburn-bg-08))))
+   `(notmuch-search-flagged-face ((t (:foreground ,zenburn-blue+1))))
+   `(notmuch-search-non-matching-authors ((t (:foreground ,zenburn-fg-1))))
+   `(notmuch-tag-added ((t (:underline ,zenburn-green+1))))
+   `(notmuch-tag-deleted ((t (:strike-through ,zenburn-red))))
+   `(notmuch-tag-face ((t (:foreground ,zenburn-green+1))))
+   `(notmuch-tag-flagged ((t (:foreground ,zenburn-blue+1))))
+   `(notmuch-tag-unread ((t (:foreground ,zenburn-red))))
+   `(notmuch-tree-match-author-face ((t (:foreground ,zenburn-green+1))))
+   `(notmuch-tree-match-tag-face ((t (:foreground ,zenburn-green+1))))
 ;;;;; org-mode
    `(org-agenda-date-today
      ((t (:foreground ,zenburn-fg+1 :slant italic :weight bold))) t)
    `(org-agenda-structure
      ((t (:inherit font-lock-comment-face))))
    `(org-archived ((t (:foreground ,zenburn-fg :weight bold))))
+   `(org-block ((t (:background ,zenburn-bg+05 :extend t))))
    `(org-checkbox ((t (:background ,zenburn-bg+2 :foreground ,zenburn-fg+1
                                    :box (:line-width 1 :style released-button)))))
    `(org-date ((t (:foreground ,zenburn-blue :underline t))))
@@ -1174,6 +1221,7 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(org-level-7 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-red-4))))
    `(org-level-8 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-blue-4))))
    `(org-link ((t (:foreground ,zenburn-yellow-2 :underline t))))
+   `(org-quote ((t (:background ,zenburn-bg+05 :extend t))))
    `(org-scheduled ((t (:foreground ,zenburn-green+4))))
    `(org-scheduled-previously ((t (:foreground ,zenburn-red))))
    `(org-scheduled-today ((t (:foreground ,zenburn-blue+1))))
@@ -1192,7 +1240,9 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(org-ellipsis ((t (:foreground ,zenburn-yellow-1 :underline t))))
    `(org-footnote ((t (:foreground ,zenburn-cyan :underline t))))
    `(org-document-title ((t (:inherit ,z-variable-pitch :foreground ,zenburn-blue
-                                         :weight bold :height ,zenburn-height-plus-4))))
+                                      :weight bold
+                                      ,@(when zenburn-scale-org-headlines
+                                          (list :height zenburn-height-plus-4))))))
    `(org-document-info ((t (:foreground ,zenburn-blue))))
    `(org-habit-ready-face ((t :background ,zenburn-green)))
    `(org-habit-alert-face ((t :background ,zenburn-yellow-1 :foreground ,zenburn-bg)))
@@ -1242,7 +1292,7 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; paren-face
    `(parenthesis ((t (:foreground ,zenburn-fg-1))))
 ;;;;; perspective
-   `(persp-selected-face ((t (:foreground ,zenburn-yellow-2 :inherit mode-line))))
+   `(persp-selected-face ((t (:foreground ,zenburn-yellow-2))))
 ;;;;; powerline
    `(powerline-active1 ((t (:background ,zenburn-bg-05 :inherit mode-line))))
    `(powerline-active2 ((t (:background ,zenburn-bg+2 :inherit mode-line))))
@@ -1331,6 +1381,10 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(rst-level-4-face ((t (:foreground ,zenburn-yellow-2))))
    `(rst-level-5-face ((t (:foreground ,zenburn-cyan))))
    `(rst-level-6-face ((t (:foreground ,zenburn-green-2))))
+;;;;; selectrum
+   `(selectrum-current-candidate ((t (:foreground ,zenburn-yellow :weight bold :underline t))))
+   `(selectrum-primary-highlight ((t (:background ,zenburn-green-2))))
+   `(selectrum-secondary-highlight ((t (:background ,zenburn-green))))
 ;;;;; sh-mode
    `(sh-heredoc     ((t (:foreground ,zenburn-yellow :weight bold))))
    `(sh-quoted-exec ((t (:foreground ,zenburn-red))))
@@ -1385,6 +1439,11 @@ Also bind `class' to ((class color) (min-colors 89))."
       (t
        (:underline ,zenburn-green))))
    `(slime-highlight-face ((t (:inherit highlight))))
+;;;;; solaire
+   `(solaire-default-face ((t (:inherit default :background ,zenburn-bg-08))))
+   `(solaire-minibuffer-face ((t (:inherit default :background ,zenburn-bg-08))))
+   `(solaire-hl-line-face ((t (:inherit hl-line :background ,zenburn-bg))))
+   `(solaire-org-hide-face ((t (:inherit org-hide :background ,zenburn-bg-08))))
 ;;;;; speedbar
    `(speedbar-button-face ((t (:foreground ,zenburn-green+2))))
    `(speedbar-directory-face ((t (:foreground ,zenburn-cyan))))
@@ -1393,20 +1452,22 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(speedbar-selected-face ((t (:foreground ,zenburn-red))))
    `(speedbar-separator-face ((t (:foreground ,zenburn-bg :background ,zenburn-blue-1))))
    `(speedbar-tag-face ((t (:foreground ,zenburn-yellow))))
+;;;;; swiper
+   `(swiper-line-face ((t (:underline t))))
 ;;;;; sx
    `(sx-custom-button
      ((t (:background ,zenburn-fg :foreground ,zenburn-bg-1
-          :box (:line-width 3 :style released-button) :height 0.9))))
+                      :box (:line-width 3 :style released-button) :height 0.9))))
    `(sx-question-list-answers
      ((t (:foreground ,zenburn-green+3
-          :height 1.0 :inherit sx-question-list-parent))))
+                      :height 1.0 :inherit sx-question-list-parent))))
    `(sx-question-mode-accepted
      ((t (:foreground ,zenburn-green+3
-          :height 1.3 :inherit sx-question-mode-title))))
+                      :height 1.3 :inherit sx-question-mode-title))))
    '(sx-question-mode-content-face ((t (:inherit highlight))))
    `(sx-question-mode-kbd-tag
      ((t (:box (:color ,zenburn-bg-1 :line-width 3 :style released-button)
-          :height 0.9 :weight semi-bold))))
+               :height 0.9 :weight semi-bold))))
 ;;;;; tabbar
    `(tabbar-button ((t (:foreground ,zenburn-fg
                                     :background ,zenburn-bg))))
@@ -1575,30 +1636,43 @@ Also bind `class' to ((class color) (min-colors 89))."
 (declare-function rainbow-mode 'rainbow-mode)
 (declare-function rainbow-colorize-by-assoc 'rainbow-mode)
 
-(defvar zenburn-add-font-lock-keywords nil
+(defcustom zenburn-add-font-lock-keywords nil
   "Whether to add font-lock keywords for zenburn color names.
+
 In buffers visiting library `zenburn-theme.el' the zenburn
-specific keywords are always added.  In all other Emacs-Lisp
-buffers this variable controls whether this should be done.
-This requires library `rainbow-mode'.")
+specific keywords are always added, provided that library has
+been loaded (because that is where the code that does it is
+defined).  If you visit this file and only enable the theme,
+then you have to turn `rainbow-mode' off and on again for the
+zenburn-specific font-lock keywords to be used.
+
+In all other Emacs-Lisp buffers this variable controls whether
+this should be done.  This requires library `rainbow-mode'."
+  :type 'boolean
+  :group 'zenburn-theme)
 
 (defvar zenburn-colors-font-lock-keywords nil)
 
-;; (defadvice rainbow-turn-on (after zenburn activate)
-;;   "Maybe also add font-lock keywords for zenburn colors."
-;;   (when (and (derived-mode-p 'emacs-lisp-mode)
-;;              (or zenburn-add-font-lock-keywords
-;;                  (equal (file-name-nondirectory (buffer-file-name))
-;;                         "zenburn-theme.el")))
-;;     (unless zenburn-colors-font-lock-keywords
-;;       (setq zenburn-colors-font-lock-keywords
-;;             `((,(regexp-opt (mapcar 'car zenburn-colors-alist) 'words)
-;;                (0 (rainbow-colorize-by-assoc zenburn-colors-alist))))))
-;;     (font-lock-add-keywords nil zenburn-colors-font-lock-keywords)))
+(defun zenburn--rainbow-turn-on ()
+  "Maybe also add font-lock keywords for zenburn colors."
+  (when (and (derived-mode-p 'emacs-lisp-mode)
+             (or zenburn-add-font-lock-keywords
+                 (and (buffer-file-name)
+                      (equal (file-name-nondirectory (buffer-file-name))
+                             "zenburn-theme.el"))))
+    (unless zenburn-colors-font-lock-keywords
+      (setq zenburn-colors-font-lock-keywords
+            `((,(regexp-opt (mapcar 'car zenburn-default-colors-alist) 'words)
+               (0 (rainbow-colorize-by-assoc zenburn-default-colors-alist))))))
+    (font-lock-add-keywords nil zenburn-colors-font-lock-keywords 'end)))
 
-;; (defadvice rainbow-turn-off (after zenburn activate)
-;;   "Also remove font-lock keywords for zenburn colors."
-;;   (font-lock-remove-keywords nil zenburn-colors-font-lock-keywords))
+(defun zenburn--rainbow-turn-off ()
+  "Also remove font-lock keywords for zenburn colors."
+  (font-lock-remove-keywords nil zenburn-colors-font-lock-keywords))
+
+(when (fboundp 'advice-add)
+  (advice-add 'rainbow-turn-on :after  #'zenburn--rainbow-turn-on)
+  (advice-add 'rainbow-turn-off :after #'zenburn--rainbow-turn-off))
 
 ;;; Footer
 
